[Bug 1954] SHNotifyCopyFileW doesn't create subdirectories (it should)

Phillip.Ezolt at hp.com Phillip.Ezolt at hp.com
Fri Jan 23 15:56:53 CST 2004


Mike,
	Here's my current patch.  I'll submitt it to wine patches
early next week after I have verified that it works with CVS.

--Phil

On Fri, 23 Jan 2004, Wine Bugs wrote:

> http://bugs.winehq.org/show_bug.cgi?id=1954
>
>
>
>
>
> ------- Additional Comments From mike at theoretic.com  2004-23-01 09:55 -------
> Can you submit a patch for this?
>
> --
> Configure bugmail: http://bugs.winehq.org/userprefs.cgi?tab=email
> ------- You are receiving this mail because: -------
> You reported the bug, or are watching the reporter.
>
-------------- next part --------------
? patch.diff
Index: dlls/shell32/shlfileop.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlfileop.c,v
retrieving revision 1.35
diff -u -r1.35 shlfileop.c
--- dlls/shell32/shlfileop.c	5 Jan 2004 21:13:37 -0000	1.35
+++ dlls/shell32/shlfileop.c	23 Jan 2004 21:39:44 -0000
@@ -1172,9 +1172,15 @@
 	    /* singlesource + no mask */
 	    if (-1 == (ToAttr & ToPathAttr))
 	    {
-                /* Target-dir does not exist, and cannot be created */
-                retCode=0x75;
-                goto shfileop_error;
+	      /* The destination directory for the file doesn't exist, create it. */
+                pToFile[0] = '\0';
+		if (SHCreateDirectoryExW(NULL,pTempTo, NULL))
+		  {
+		    // Target-dir does not exist, and cannot be created 
+		    retCode=0x75;
+		    goto shfileop_error;
+		  }
+                pToFile[0] = '\\';
 	    }
 
 	    switch(FuncSwitch)


More information about the wine-bugs mailing list